@@ -47,7 +47,7 @@ class ActInfoHandler(ClientBaseHandler):
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
         act_info_dict = act_base_model.get_act_info_dict(act_id, True, False)
-        if not act_info_dict:
+        if not act_info_dict or act_info_dict["is_del"] == 1:
             return self.response_json_error("error", "活动不存在")
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -103,11 +103,12 @@ class ActInfoHandler(ClientBaseHandler):
         #品牌配置
         act_info_dict["brands"] = SevenHelper.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}
         act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
-        for item in exclude_fields.split(','):
-            try:
-                del act_info_dict[item]
-            except:
-                pass
+        if act_info_dict:
+            for item in exclude_fields.split(','):
+                try:
+                    del act_info_dict[item]
+                except:
+                    pass
         return self.response_json_success(act_info_dict)
 
 
