@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2023-03-23 10:22:09
+@LastEditTime: 2023-03-30 10:30:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -708,13 +708,13 @@ class BrowseStoreHandler(ClientBaseHandler):
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else False  #是否统计
         is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_routine_task(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, task_type,task_sub_type, False, check_user_nick)
+        invoke_result_data = task_base_model.process_routine_task(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, task_type, task_sub_type, False, check_user_nick)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data = invoke_result_data.data if invoke_result_data.data else {}
         invoke_result_data.data["reward_value"] = 0
         if is_receive_reward == True:
-            reward_invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=is_stat, info_json=info_json, check_act_info_release=False, check_act_module_release=False)
+            reward_invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token='', task_id=0, task_sub_type=task_sub_type, handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=is_stat, info_json=info_json, check_act_info_release=False, check_act_module_release=False)
             if reward_invoke_result_data.success == True:
                 invoke_result_data.data["reward_value"] = reward_invoke_result_data.data["reward_value"]
         ref_params = {}
@@ -764,7 +764,7 @@ class BrowseLiveRoomHandler(ClientBaseHandler):
         invoke_result_data.data = invoke_result_data.data if invoke_result_data.data else {}
         invoke_result_data.data["reward_value"] = 0
         if is_receive_reward == True:
-            reward_invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=is_stat, info_json=info_json, check_act_info_release=False, check_act_module_release=False)
+            reward_invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token='', task_id=0, task_sub_type=task_sub_type, handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=is_stat, info_json=info_json, check_act_info_release=False, check_act_module_release=False)
             if reward_invoke_result_data.success == True:
                 invoke_result_data.data["reward_value"] = reward_invoke_result_data.data["reward_value"]
         ref_params = {}
