@@ -19,12 +19,14 @@ class ThemeInfoListHandler(ClientBaseHandler):
         """
         :description: 主题列表
         :param app_id：应用标识
+        :param ascription_type：归属类型
         :return: 列表
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
+        ascription_type = self.get_param_int("ascription_type", 1)
         theme_base_model = ThemeBaseModel(context=self)
-        return self.response_json_success(theme_base_model.get_theme_list(app_id,is_cache=False))
+        return self.response_json_success(theme_base_model.get_theme_list(app_id, is_cache=False, ascription_type=ascription_type))
 
 
 class SkinInfoListHandler(ClientBaseHandler):
