@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2023-01-18 16:46:44
+@LastEditTime: 2023-02-17 09:26:10
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -43,21 +43,22 @@ class ActBaseModel():
             dependency_key_list.append(DependencyKey.act_info_list(app_id))
         ActInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
 
-    def get_act_info_dict(self,act_id,is_cache=True,is_filter=True):
+    def get_act_info_dict(self,act_id,is_cache=True,is_filter=True, field="*"):
         """
         :description: 获取活动信息
         :param act_id: 活动标识
         :param is_cache: 是否缓存
         :param is_filter: 是否过滤未发布或删除的数据
+        :param field: 查询字段
         :return: 返回活动信息
         :last_editors: HuangJianYi
         """
         act_info_model = ActInfoModel(context=self.context)
         if is_cache:
             dependency_key = DependencyKey.act_info(act_id)
-            act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=dependency_key)
+            act_info_dict = act_info_model.get_cache_dict_by_id(primary_key_id=act_id, dependency_key=dependency_key, field=field)
         else:
-            act_info_dict = act_info_model.get_dict_by_id(act_id)
+            act_info_dict = act_info_model.get_dict_by_id(act_id, field)
         if is_filter == True:
             if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
                 return None
