@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2023-02-10 10:22:23
+@LastEditTime: 2023-03-28 15:07:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -161,18 +161,21 @@ class AppBaseModel():
         base_info["server_ver"] = base_info_dict["server_ver"]
         base_info["is_force_update"] = base_info_dict["is_force_update"]
         base_info["is_force_phone"] = share_config.get_value("is_force_phone",True)
-        #中台指定账号升级
-        version_info = VersionInfoModel(context=self.context).get_entity(where="type_id=1",order_by="id desc")
-        if version_info:
-            if version_info.update_scope == 2 and version_info.white_lists:
-                white_lists = list(set(str(version_info.white_lists).split(',')))
-                if user_nick in white_lists:
-                    base_info["client_ver"] = version_info.version_number
+        
         #配置文件指定账号升级
-        if user_nick:
-            test_config = share_config.get_value("test_config",{})
-            if user_nick == test_config.get("user_nick",""):
-                base_info["client_ver"] = test_config.get("client_ver","")
+        test_config = share_config.get_value("test_config",{})
+        test_client_ver = test_config.get("client_ver","")
+        if test_client_ver and store_user_nick and store_user_nick == test_config.get("user_nick",""):
+            base_info["client_ver"] = test_client_ver
+        else:
+            #中台指定账号升级
+            version_info = VersionInfoModel(context=self.context).get_entity(where="type_id=1",order_by="id desc")
+            if version_info:
+                if version_info.update_scope == 2 and version_info.white_lists:
+                    white_lists = SevenHelper.json_loads(version_info.white_lists)
+                    if store_user_nick in white_lists:
+                        base_info["client_ver"] = version_info.version_number
+
         data["base_info"] = base_info
         invoke_result_data.data =data
         return invoke_result_data
