@@ -120,7 +120,7 @@ class CacheModel(BaseModel):
         if hasattr(self, "db") and share_config.get_value("log_redis_cache",True):
             if hasattr(self.db, "context"):
                 if hasattr(self.db.context, "logging_link_info"):
-                    log_info = {"sql":sql, "params":params, "result":cache_data, "dependency_key":dependency_key, "cache_key":cache_key}
+                    log_info = {"sql":sql, "params":params, "result":cache_data, "dependency_key":dependency_key, "cache_key":self.get_dependency_cache_key(dependency_key,cache_key)}
                     self.db.context.logging_link_info("data_cache:" + JsonHelper.json_dumps(log_info))
 
     def set_dependency_cache(self, dependency_key, cache_key, value, cache_expire):
