@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-03-09 18:53:01
+@LastEditTime: 2023-03-29 17:55:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -45,16 +45,17 @@ class OrderBaseModel(FrameBaseModel):
         """
         PrizeOrderModel().delete_dependency_key(DependencyKey.prize_order_list(act_id,user_id), delay_delete_time)
         
-    def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
+    def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1, app_id=''):
         """
         :description: 删除中奖记录依赖建
         :param act_id: 活动标识
         :param user_id: 用户标识
         :param delay_delete_time: 延迟删除时间，传0则不进行延迟
+        :param app_id: 应用标识
         :return: 
         :last_editors: HuangJianYi
         """
-        PrizeRosterModel().delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id), delay_delete_time)
+        PrizeRosterModel().delete_dependency_key(DependencyKey.prize_roster_list(act_id, user_id, app_id), delay_delete_time)
 
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None, page_count_mode="total"):
         """
@@ -499,7 +500,7 @@ class OrderBaseModel(FrameBaseModel):
             result,message = db_transaction.commit_transaction(True)
             if result == False:
                 raise Exception("执行事务失败",message)
-            prize_roster_model.delete_dependency_key([DependencyKey.prize_roster_list(act_id, user_id),DependencyKey.prize_order_list(act_id,user_id)])
+            prize_roster_model.delete_dependency_key([DependencyKey.prize_roster_list(act_id, user_id, app_id),DependencyKey.prize_order_list(act_id,user_id)])
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
@@ -513,7 +514,7 @@ class OrderBaseModel(FrameBaseModel):
 
         SevenHelper.redis_release_lock(acquire_lock_name, identifier)
         self._delete_prize_order_dependency_key(act_id,user_id)
-        self._delete_prize_roster_dependency_key(act_id, user_id)
+        self._delete_prize_roster_dependency_key(act_id=act_id, user_id=user_id, app_id=app_id)
         invoke_result_data.data = prize_order.__dict__
         return invoke_result_data
 
@@ -859,7 +860,7 @@ class OrderBaseModel(FrameBaseModel):
 
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
-            page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, condition_where.to_string(), "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id), page_count_mode=page_count_mode)
+            page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, condition_where.to_string(), "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id,app_id), page_count_mode=page_count_mode)
         else:
             page_list = prize_roster_model.get_dict_page_list(field, page_index, page_size, condition_where.to_string(), "", order_by, params_list, page_count_mode)
         return page_list
@@ -984,7 +985,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="未授权请联系客服授权"
             return invoke_result_data
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
-        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=DependencyKey.prize_roster_list(act_id,user_id))
+        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=DependencyKey.prize_roster_list(act_id,user_id,app_id))
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -1008,14 +1009,14 @@ class OrderBaseModel(FrameBaseModel):
         if resp["alibaba_benefit_send_response"]:
             if resp["alibaba_benefit_send_response"]["result_success"] == True:
                 prize_roster_model.update_table("prize_status=1", "id=%s", params=[user_prize_id])
-                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id))
+                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id,app_id))
                 result = {}
                 result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
                 invoke_result_data.data = result
                 return invoke_result_data
             if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
                 prize_roster_model.update_table("prize_status=10", "id=%s", params=[user_prize_id])
-                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id))
+                prize_roster_model.delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id,app_id))
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message ="领取失败：优惠券无效或已删除"
