@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2023-02-22 14:48:32
+@LastEditTime: 2023-03-29 17:13:54
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -323,17 +323,21 @@ class DependencyKey():
         return dependency_key
 
     @classmethod
-    def prize_roster_list(self, act_id, user_id=0):
+    def prize_roster_list(self, act_id, user_id=0, app_id=''):
         """
         :description: 中奖记录列表
         :param act_id: 活动标识
         :param user_id: 用户标识
+        :param app_id: 应用标识
         :return str
         :last_editors: HuangJianYi
         """
+        act_id = act_id if act_id > 0 else 0
         dependency_key = f"prize_roster_list:actid_{act_id}"
         if user_id:
             dependency_key += f"_userid_{user_id}"
+        if act_id == 0 and app_id:
+            dependency_key += f"_appid_{app_id}"
         return dependency_key
 
     @classmethod
