@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2023-03-13 11:31:44
+@LastEditTime: 2023-03-29 12:00:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -58,26 +58,32 @@ class ThemeBaseModel():
             redis_init.set(cache_key, SevenHelper.json_dumps(theme_info_dict), ex=share_config.get_value("cache_expire", 600))
         return theme_info_dict
 
-    def get_theme_list(self,app_id,is_public=True,is_cache=True):
+    def get_theme_list(self,app_id, is_public=True, is_cache=True, ascription_type=-1):
         """
         :description: 获取主题列表
         :param app_id：应用标识
         :param is_public：是否读取公共的（True是False否）
         :param is_cache：是否缓存
+        :param ascription_type：归属类型
         :return: 获取主题列表
         :last_editors: HuangJianYi
         """
-        where = "is_release=1"
+        condition_where = ConditionWhere()
+        condition_where.add_condition("is_release=1")
+        params = []
+        if ascription_type != -1:
+            condition_where.add_condition("ascription_type=%s")
+            params.append(ascription_type)
         if is_public == True:
-            where += " and (app_id=%s or app_id='')"
+            condition_where.add_condition("(app_id=%s or app_id='')")
         else:
-            where += " and app_id=%s"
-        params = [app_id]
+            condition_where.add_condition("app_id=%s")
+        params.append(app_id)
         theme_info_model = ThemeInfoModel(context=self.context)
         if is_cache:
-            dict_list = theme_info_model.get_cache_dict_list(where=where, params=params)
+            dict_list = theme_info_model.get_cache_dict_list(where=condition_where.to_string(), params=params)
         else:
-            dict_list = theme_info_model.get_dict_list(where=where, params=params)
+            dict_list = theme_info_model.get_dict_list(where=condition_where.to_string(), params=params)
 
         for dict_info in dict_list:
             dict_info["server_json"] = SevenHelper.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}
