@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2023-02-27 09:48:56
+@LastEditTime: 2023-03-23 10:16:34
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1163,6 +1163,31 @@ class TopBaseModel():
                 if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
                     is_member = True
         return is_member
+    
+    def get_member_grade(self, mix_nick, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 查询会员等级
+        :param mix_nick:mix_nick
+        :param access_token:access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return:会员信息
+        :last_editors: HuangJianYi
+        """
+        member_info = {}
+        invoke_result_data = self.get_member_info(mix_nick,'', access_token, app_key, app_secret, is_log)
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        resp = invoke_result_data.data
+        if "crm_member_identity_get_response" in resp.keys():
+                if "result" in resp["crm_member_identity_get_response"].keys():
+                    if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
+                        if "grade" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys() and "grade_name" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys():
+                            member_info = resp["crm_member_identity_get_response"]["result"]["member_info"]
+        
+        invoke_result_data.data = member_info
+        return invoke_result_data
 
     def get_join_member_url(self, access_token, app_key, app_secret, is_log=False):
         """
