@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2023-02-23 14:11:16
+@LastEditTime: 2023-03-24 20:25:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -587,7 +587,7 @@ class UserBaseModel(FrameBaseModel):
             user_info.user_state = 0
             user_info.modify_date = audit_date
             user_info.relieve_date = audit_date
-            user_info_model.update_entity(user_info, "user_state,modify_date,modify_date")
+            user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
         elif audit_status == 3:
             user_black_model.update_table(condition, "id=%s", params)
 
